# Configuration file for the Sphinx documentation builder.
#
# For the full list of built-in configuration values, see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Project information -----------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#project-information

project = 'avulto'
copyright = '2024 Warriorstar Orion'
author = 'Warriorstar Orion'
release = 'v0.0.20'
version = release


extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.autosummary',
    'sphinx.ext.intersphinx',
    # 'sphinx.ext.todo',
    # 'sphinx.ext.inheritance_diagram',
    # 'sphinx.ext.autosectionlabel',
    # 'sphinx.ext.napoleon',
    # 'sphinx_rtd_theme',
]

autosummary_generate = True
autosummary_imported_members = True

intersphinx_mapping = {
    'python': ('https://docs.python.org/3', None),
    'Pillow': ('https://pillow.readthedocs.io/en/stable/', None),
}

templates_path = ['_templates']
exclude_patterns = []

# -- Options for HTML output -------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output

# html_theme = 'sphinx_rtd_theme'
html_theme = 'alabaster'
# html_static_path = ['_static']
# html_css_files = [
#     'custom.css',
# ]
# html_permalinks = False
# html_permalinks_icon = "BLAH"
# html_add_permalinks = "X"
# html_permalinks_icon = 'X'

# html_sidebars = {
#     # '**': [
#     #     'index.html',
#     #     # 'navigation.html',
#     #     # 'relations.html',
#     #     # 'searchbox.html',
#     #     # 'donate.html',
#     # ]
# }

html_sidebars = {
   '**': ['globaltoc.html', 'sourcelink.html', 'searchbox.html'],
}

# html_theme_options = {
#     "body_text": "#ccc",
#     "link": "#eee",
# }



import os

import pytest

from avulto import DME


def get_fixture_path(name):
    return os.path.join(os.path.dirname(os.path.abspath(__file__)), "fixtures", name)


@pytest.fixture
def dme() -> DME:
    return DME.from_file(get_fixture_path("testenv.dme"))


def test_dme_typesof(dme: DME):
    foo_types = {
        "/obj/foo",
        "/obj/foo/bar",
        "/obj/foo/baz",
    }
    assert sorted(dme.typesof("/obj/foo")) == sorted(foo_types)
    assert dme.subtypesof("/obj/foo") == [
        "/obj/foo/bar",
        "/obj/foo/baz",
    ]

    datum_subtypes = dme.subtypesof("/datum")
    assert all([x in datum_subtypes for x in foo_types])


def test_missing_type(dme: DME):
    with pytest.raises(RuntimeError) as ex:
        dme.typedecl("/missing_type")

    assert str(ex.value) == "cannot find path /missing_type"


def test_dme_vars(dme: DME):
    foo = dme.typedecl("/obj/foo")
    assert foo.var_names() == ["a", "icon", "icon_state"]
    assert foo.value("a") == 3

    bar = dme.typedecl("/obj/foo/bar")
    assert bar.var_names() == ["a"]
    assert bar.value("a") == 4

    baz = dme.typedecl("/obj/foo/baz")
    assert baz.value("a") == 3


def test_dme_procs(dme: DME):
    foo = dme.typedecl("/obj/foo")
    assert sorted(foo.proc_names()) == ["proc1", "proc2"]



import os

import pytest

from avulto import DME


def get_fixture_path(name):
    return os.path.join(os.path.dirname(os.path.abspath(__file__)), "fixtures", name)


@pytest.fixture
def dme() -> DME:
    return DME.from_file(get_fixture_path("testenv.dme"), parse_procs=True)


def test_walker_base(dme: DME):
    class VarAndReturnWalker:
        pass

    varw = VarAndReturnWalker()
    dme.walk_proc("/obj/test_object", "var_and_return", varw)
